
# FullCalendar Luxon Plugin

A connector to the Luxon date library

[View the docs &raquo;](https://fullcalendar.io/docs/luxon-plugin)

This package was created from the [FullCalendar monorepo &raquo;](https://github.com/fullcalendar/fullcalendar)
